@@ -7,13 +7,13 @@
 #include <tqlabel.h>
 #include <tqtimer.h>
 
-namespace KIO { class Job; }
+namespace TDEIO { class Job; }
 
 
 class ProgressBox : public TQLabel
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     ProgressBox( TQWidget*, TQObject* );
